import React, { useEffect } from 'react';
import './login.css';
import { login } from '@/utils/requests/user/login';
import { useBoxAnimation } from '@/utils/boxAnimation';
import { NavigateFunction, useNavigate } from 'react-router-dom';

const handleLogin = async (event: React.FormEvent<HTMLFormElement>, navigate: NavigateFunction) => {
    event.preventDefault();
    try {
        const formData = new FormData(event.currentTarget);
        console.log(formData);

        const email = formData.get('email') as string;
        const password = formData.get('password') as string;
        const response = await login(email, password);
        console.log(response);
        navigate('/profile');
    } catch (err) {
        console.error(err);
    }
}

const LoginPage: React.FC = () => {
    const navigate = useNavigate();
    const { clearImages } = useBoxAnimation();
    useEffect(() => {
        return clearImages;
    }, []);
    return (
        <>
            <img src="McGuild_Sword.png" alt="McGuild Logo" />
            <form onSubmit={(e) => handleLogin(e, navigate)}>
                <div className="formBox">

                    <div className="formField">
                        <label htmlFor="email">McGill Email:</label>
                        <input type="text" name="email" id="email" required />
                    </div>

                    <div className="formField">
                        <label htmlFor="password">Password:</label>
                        <input type="password" name="password" id="password" required />
                    </div>

                </div>

                <div className="buttonBox">
                    {/*Real one <button type="submit" className="button login">log in</button> */}
                    {/* Blow one For testing */}
                    <button type="submit" className="button login" onClick={() => {navigate('/boards/userboards')}}>log in</button> 
                    <button className="button cancel" onClick={() => navigate('/')}>cancel</button>
                </div>
            </form>
        </>
    );
};

export default LoginPage;
