import { Request, Response } from "express";
import { CallbackWithoutResultAndOptionalError } from "mongoose";
import Board from "@/models/board/board";
import { IRequest } from "@/types/requests/session";
import Channel from "@/models/channel/channel";
import Message from "@/models/message/message";

const removeMessage = async (req: Request, res: Response, next: CallbackWithoutResultAndOptionalError) => {
    const ireq = req as IRequest;
    const userData = ireq.session.user;
    const board = await Board.findById(req.params.boardId);
    if (board === null) {
        res.status(400).json({ message: "Board does not exist" });
        return;
    }
    if (!board.users.includes(userData._id)) {
        res.status(401).json({ message: "Permission denied" });
        return;
    }
    const channel = await Channel.findById(req.params.channelId);
    if (channel === null) {
        res.status(400).json({ message: "Channel does not exist" });
        return;
    }
    if (channel.is_DM) {
        res.status(400).json({ message: "Message could not be created" });
        return;
    }
    if (!channel.users.includes(userData._id)) {
        res.status(401).json({ message: "Permission denied" });
        return;
    }
    const message = await Message.findById(req.params.messageId);
    if (message === null) {
        res.status(400).json({ message: "Message does not exist" });
        return;
    }
    if (!channel._id.equals(message.channelId)) {
        res.status(400).json({ message: "Message could not be deleted" });
        return;
    }
    if (!userData._id.equals(message.user._id)) {
        res.status(401).json({ message: "Permission denied" });
        return;
    }
    await Message.deleteOne({ _id: req.params.messageId });
    res.status(200).json({ message: "Message removed successfully!", success: true });
    next();
};

export default removeMessage;