import { Request, Response } from "express";
import { CallbackWithoutResultAndOptionalError } from "mongoose";
import Board from "@/models/board/board";
import { IRequest } from "@/types/requests/session";
import Channel from "@/models/channel/channel";
import User from "@/models/user/user";

const addMemberChannel = async (req: Request, res: Response, next: CallbackWithoutResultAndOptionalError) => {
    const ireq = req as IRequest;
    const userData = ireq.session.user;
    const board = await Board.findById(req.params.boardId);
    if (board === null)
    {
        res.status(400).json({ message: "Board does not exist" });
        return;
    }
    if (!board.admin.equals(userData._id)) {
        res.status(401).json({ message: "Permission denied" });
        return;
    }
    const channel = await Channel.findById(req.params.channelId);
    if (channel === null) {
        res.status(400).json({ message: "Channel does not exist" });
        return;
    }
    if (!board.channels.includes(channel._id)) {
        res.status(400).json({ message: "Could not add member" });
        return;
    }
    if (channel.is_DM) {
        res.status(400).json({ message: "Could not be added" });
        return;
    }
    const userToAdd = await User.findOne({ email: req.body.email });
    if (userToAdd === null) {
        res.status(400).json({ message: "The user does not exist" });
        return;
    }
    if (!board.users.includes(userToAdd._id)) {
        res.status(400).json({ message: "Can only add members of the board" });
        return;
    }
    if (board.channels.includes(userToAdd._id)) {
        res.status(400).json({ message: "User is already a member of the channel" });
        return;
    }
    const update = await Channel.updateOne({ _id: req.params.channelId }, { $push: { users: userToAdd } }, { new: true });
    res.status(200).json({ message: "User successfully added to the channel", update, success: true});
    next();
};

export default addMemberChannel;