import { Request, Response } from "express";
import { CallbackWithoutResultAndOptionalError } from "mongoose";
import Board from "@/models/board/board";
import { IRequest } from "@/types/requests/session";
import Channel from "@/models/channel/channel";

const addChannel = async (req: Request, res: Response, next: CallbackWithoutResultAndOptionalError) => {
    try{
        const ireq = req as IRequest;
        const userData = ireq.session.user;
        const board = await Board.findById(req.params.boardId);
        if (board === null)
        {
            res.status(400).json({ message: "Board does not exist" });
            return;
        }
        if (!board.admin.equals(userData._id)) {
            res.status(401).json({ message: "Permission denied" });
            return;
        }
        const channel = await Channel.create({ name: req.body.name, users: [], is_DM: false });
        const update = await Board.updateOne({ _id: req.params.boardId }, { $push: { channels: channel } }, { new: true });
        res.status(200).json({ message: "Channel created successfully!", update, success: true });
        next();
    } catch (error: any) {
        next(error);
    }
};

export default addChannel;