import { Request, Response } from "express";
import { CallbackWithoutResultAndOptionalError } from "mongoose";
import Board from "@/models/board/board";
import { IRequest } from "@/types/requests/session";

const refreshChannelsBoard = async (req: Request, res: Response, next: CallbackWithoutResultAndOptionalError) => {
    try {
        const ireq = req as IRequest;
        const userData = ireq.session.user;
        const board = await Board.findOne({ _id: req.params.boardId });
        if (board === null) {
            res.status(400).json({ message: "Board does not exist" });
            return;
        }
        if (!board.users.includes(userData._id)) {
            res.status(401).json({ message: "Permission denied" });
            return;
        }
        await board.populate("channels");
        const channels = board.channels;
        res.status(200).json({ message: "Refreshed channels!", channels, success: true });
        next();
    } catch (error: any) {
        next(error);
    }
};

export default refreshChannelsBoard;