import { Request, Response } from "express";
import { CallbackWithoutResultAndOptionalError } from "mongoose";
import Board from "@/models/board/board";
import { IRequest } from "@/types/requests/session";
import Channel from "@/models/channel/channel";
import Message from "@/models/message/message";

const removeChannel = async (req: Request, res: Response, next: CallbackWithoutResultAndOptionalError) => {
    try{
        const ireq = req as IRequest;
        const userData = ireq.session.user;
        const board = await Board.findById(req.params.boardId);
        if (board === null)
        {
            res.status(400).json({ message: "Board does not exist" });
            return;
        }
        if (!board.admin.equals(userData._id)) {
            res.status(401).json({ message: "Permission denied" });
            return;
        }
        const channel = await Channel.findById(req.params.channelId);
        if (channel === null) {
            res.status(400).json({ message: "Channel does not exist" });
            return;
        }
        if (!board.channels.includes(channel._id)) {
            res.status(400).json({ message: "Could not be removed" });
            return;
        }
        if (channel.is_DM) {
            res.status(400).json({ message: "Could not be removed" });
            return;
        }
        await Board.updateOne({ _id: req.params.boardId }, { $pull: { channels: channel._id } });
        await Message.deleteMany({ channelId: req.params.channelId });
        await Channel.deleteOne({ _id: req.params.channelId });
        res.status(200).json({ message: "Channel removed successfully!", success: true });
        next();
    } catch (error: any) {
        next(error);
    }
};

export default removeChannel;