import { Request, Response } from "express";
import { CallbackWithoutResultAndOptionalError } from "mongoose";
import Board from "@/models/board/board";
import { IRequest } from "@/types/requests/session";
import User from "@/models/user/user";

const addMemberBoard = async (req: Request, res: Response, next: CallbackWithoutResultAndOptionalError) => {
    try {
        const ireq = req as IRequest;
        const userData = ireq.session.user;
        const board = await Board.findById(req.params.boardId);
        if (board === null)
        {
            res.status(400).json({ message: "Board does not exist" });
            return;
        }
        if (!board.admin.equals(userData._id))
        {
            res.status(401).json({ message: "Permission denied" });
            return;
        }
        const userToAdd = await User.findOne({ email: req.body.email });
        if (userToAdd === null)
        {
            res.status(400).json({ message: "User does not exist" });
            return;
        }
        if (board.users.includes(userToAdd._id))
        {
            res.status(400).json({ message: "User is already a member" });
            return;
        }
        const update = await Board.updateOne({ _id: req.params.boardId }, { $push: { users: userToAdd } }, { new: true });
        res.status(200).json({ message: "Successfully added new member!", update, sucesss: true })
        next();
    } catch (error: any) {
        next(error);
    }
};

export default addMemberBoard;