import { Request, Response } from "express";
import { CallbackWithoutResultAndOptionalError } from "mongoose";
import Board from "@/models/board/board";
import { IRequest } from "@/types/requests/session";

const refreshMembersBoard = async (req: Request, res: Response, next: CallbackWithoutResultAndOptionalError) => {
    try {
        const ireq = req as IRequest;
        const userData = ireq.session.user;
        const board = await Board.findOne({ _id: req.params.boardId }, "users");
        if (board === null) {
            res.status(400).json({ message: "Board does not exist" });
            return;
        }
        if (!board.users.includes(userData._id)) {
            res.status(401).json({ message: "Permission denied" });
            return;
        }
        const result = await board.populate("users");
        res.status(200).json({ message: "Refreshed members!", result, success: true });
        next();
    } catch (error: any) {
        next(error);
    }
};

export default refreshMembersBoard;