import { Request, Response } from "express";
import { CallbackWithoutResultAndOptionalError } from "mongoose";
import Board from "@/models/board/board";
import { IRequest } from "@/types/requests/session";
import User from "@/models/user/user";
import Channel from "@/models/channel/channel";

const removeMemberBoard = async (req: Request, res: Response, next: CallbackWithoutResultAndOptionalError) => {
    try {
        const ireq = req as IRequest;
        const userData = ireq.session.user;
        const board = await Board.findById(req.params.boardId);
        if (board === null)
        {
            res.status(400).json({ message: "Board does not exist" });
            return;
        }
        if (!board.admin.equals(userData._id))
        {
            res.status(401).json({ message: "Permission denied" });
            return;
        }
        const userToRemove = await User.findById(req.params.userId);
        if (userToRemove === null)
        {
            res.status(400).json({ message: "User does not exist" });
            return;
        }
        if (!board.users.includes(userToRemove._id))
        {
            res.status(400).json({ message: "User is not a member" });
            return;
        }
        if (userToRemove._id.equals(userData._id))
        {
            res.status(400).json({ message: "Admin cannot be removed" });
            return;
        }
        for (const channel of board.channels) {
            await Channel.updateOne({ _id: channel._id }, { $pull: { users: userToRemove._id } });
        }
        const update = await Board.updateOne({ _id: req.params.boardId }, { $pull: { users: userToRemove._id } }, { new: true });
        res.status(200).json({ message: "Successfully removed member!", update, sucesss: true })
        next();
    } catch (error: any) {
        next(error);
    }
};

export default removeMemberBoard;